@@ -259,28 +259,35 @@ class WriteShellConfig(SetupTask):
     description = "Write the MWC shell configuration file ~/.mwc_rc"
 
     def is_complete(self):
-        return False
+        p = get_mwc_rc_path()
+        return p.exists() and p.read_text() == self.generate_shell_config()
 
     def run_task(self):
         click.echo(address("Writing the MWC shell configuration file..."))
-        with get_mwc_rc_path().open('w') as fh:
-            shell = get_shell_name()
-            fh.write("# Making With Code RC File\n\n")
-            fh.write("## Add Poetry to $PATH\n")
-            fh.write('export PATH="$HOME/.local/bin:$PATH"\n\n')
-            if Platform.detect() == Platform.MAC:
-                if self.settings['editor'] == "subl":
-                    fh.write("## Add subl to $PATH\n")
-                    fh.write('export PATH="/Applications/Sublime Text.app/Contents/SharedSupport/bin:$PATH"\n\n')
-            if Platform.detect() == Platform.WSL:
-                if self.settings['editor'] == "subl":
-                    fh.write("## Create subl alias for Sublime Text\n")
-                    fh.write('alias subl=\'"/mnt/c/Program Files/Sublime Text 3/subl.exe"\'')
-                if self.settings['editor'] == "atom":
-                    fh.write("## Create atom alias\n")
-                    fh.write('alias atom=”/mnt/c/Windows/System32/cmd.exe /c \'atom\'"\n\n')
+        get_mwc_rc_path().write_text(self.generate_shell_config())
         run(f"source {get_mwc_rc_path()}", shell=True, check=True)
 
+    def generate_shell_config(self):
+        "Generates the shell configuration file contents"
+        f = ""
+        shell = get_shell_name()
+        f += "# Making With Code RC File\n\n" 
+        f += "## Add Poetry to $PATH\n"
+        f += 'export PATH="$HOME/.local/bin:$PATH"\n\n'
+        if Platform.detect() == Platform.MAC:
+            if self.settings['editor'] == "subl":
+                f += "## Add subl to $PATH\n"
+                subldir = "/Applications/Sublime Text.app/Contents/SharedSupport/bin"
+                f += f'export PATH="{subldir}:$PATH"\n\n'
+        if Platform.detect() == Platform.WSL:
+            if self.settings['editor'] == "subl":
+                f += "## Create subl alias for Sublime Text\n"
+                f += 'alias subl=\'"/mnt/c/Program Files/Sublime Text 3/subl.exe"\''
+            if self.settings['editor'] == "atom":
+                f += "## Create atom alias\n"
+                f += 'alias atom=”/mnt/c/Windows/System32/cmd.exe /c \'atom\'"\n\n'
+        return f
+
 class InstallPackage(SetupTask):
     package_name = "package"
     brew_name = "package"
